==> opennms-detectorclient-rpc-21.0.0-20170731.152236-45-sources.jar: org/opennms/netmgt/provision/dns/client/rpc/DnsLookupRequestDTO.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.provision.dns.client.rpc;

import java.util.Objects;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;

import org.opennms.core.rpc.api.RpcRequest;

@XmlRootElement(name = "dns-lookup-request")
@XmlAccessorType(XmlAccessType.NONE)
public class DnsLookupRequestDTO implements RpcRequest {

    @XmlAttribute(name = "location")
    private String location;

    @XmlAttribute(name = "host-request")
    private String hostRequest;

    @XmlAttribute(name = "query-type")
    private QueryType queryType;

    @Override
    public String getLocation() {
        return location;
    }

    @Override
    public Long getTimeToLiveMs() {
        return null;
    }

    public String getHostRequest() {
        return hostRequest;
    }

    public void setHostRequest(String hostRequest) {
        this.hostRequest = hostRequest;
    }

    public void setLocation(String location) {
        this.location = location;
    }

    public QueryType getQueryType() {
        return this.queryType == null ? QueryType.LOOKUP : this.queryType;
    }

    public void setQueryType(QueryType queryType) {
        this.queryType = queryType;
    }

    @Override
    public int hashCode() {
        return Objects.hash(location, hostRequest, queryType);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        DnsLookupRequestDTO other = (DnsLookupRequestDTO) obj;
        return Objects.equals(this.location, other.location)
                && Objects.equals(this.hostRequest, other.hostRequest)
                && Objects.equals(this.queryType, other.queryType);
    }

}

==> opennms-detectorclient-rpc-22.0.0-20180425.061922-118-sources.jar: org/opennms/netmgt/provision/dns/client/rpc/DnsLookupRequestDTO.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.provision.dns.client.rpc;

import java.util.Objects;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;

import org.opennms.core.rpc.api.RpcRequest;

@XmlRootElement(name = "dns-lookup-request")
@XmlAccessorType(XmlAccessType.NONE)
public class DnsLookupRequestDTO implements RpcRequest {

    @XmlAttribute(name = "location")
    private String location;

    @XmlAttribute(name="system-id")
    private String systemId;

    @XmlAttribute(name = "host-request")
    private String hostRequest;

    @XmlAttribute(name = "query-type")
    private QueryType queryType;

    @Override
    public String getLocation() {
        return location;
    }

    public void setSystemId(String systemId) {
        this.systemId = systemId;
    }

    @Override
    public String getSystemId() {
        return systemId;
    }

    @Override
    public Long getTimeToLiveMs() {
        return null;
    }

    public String getHostRequest() {
        return hostRequest;
    }

    public void setHostRequest(String hostRequest) {
        this.hostRequest = hostRequest;
    }

    public void setLocation(String location) {
        this.location = location;
    }

    public QueryType getQueryType() {
        return this.queryType == null ? QueryType.LOOKUP : this.queryType;
    }

    public void setQueryType(QueryType queryType) {
        this.queryType = queryType;
    }

    @Override
    public int hashCode() {
        return Objects.hash(location, systemId, hostRequest, queryType);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        DnsLookupRequestDTO other = (DnsLookupRequestDTO) obj;
        return Objects.equals(this.location, other.location)
                && Objects.equals(this.systemId, other.systemId)
                && Objects.equals(this.hostRequest, other.hostRequest)
                && Objects.equals(this.queryType, other.queryType);
    }

}
